@@ -8,7 +8,6 @@ Created on Sun Feb 21 08:31:01 2021
 import os
 import json
 from datetime import datetime, date, time
-import jsonpickle
 import boto3
 from botocore.client import Config
 from botocore.exceptions import ClientError, ParamValidationError
@@ -16,7 +15,6 @@ from loguru import logger
 
 from wud.helper import logger_wraps, timeit, EnhancedJSONEncoder,EnhancedJSONDecoder
 
-jsonpickle.set_encoder_options('json', sort_keys=False, indent=4)
 
 #%% AWS S3
             
@@ -46,7 +44,7 @@ def get_s3_object(client_resource):
     if client_resource == 'client':
         s3 = boto3.client(
         "s3",
-        region_name = 'ap-southeast-1',
+        region_name = 'us-east-1',
         aws_access_key_id = os.environ.get('AWS_ACCESS_KEY_ID'),
         aws_secret_access_key = os.environ.get('AWS_SECRET_ACCESS_KEY'),
         config=Config(signature_version='s3v4')
