@@ -120,4 +120,45 @@ def team_name_revise(team, source_input, source_output):
         if(source_output=='abbv'):
             result = result[:3]
             
-    return result       
+    return result
+
+def get_hdc_result(hdc, hdc_side, score_home, score_away):
+    
+    hdc = float(hdc)
+    score_home = float(score_home)
+    score_away = float(score_away)
+    
+    if hdc_side == 'home':
+        score_away = score_away + hdc
+    else:
+        score_home = score_home + hdc
+    
+    if score_home - score_away > 0.25:
+        hdc_side_win = 'home'
+        return_factor = 1
+        
+    elif score_home - score_away == 0.25:
+        hdc_side_win = 'home'
+        return_factor = 0.5
+        
+    elif score_home - score_away == 0:
+        hdc_side_win = 'home'
+        return_factor = 0
+        
+    elif score_home - score_away == -0.25:
+        hdc_side_win = 'away'
+        return_factor = 0.5
+
+    else:        
+        hdc_side_win = 'away'
+        return_factor = 1
+
+    return (hdc_side_win, return_factor)    
+
+def get_hdc_return(hdc_side_win, return_factor , play_side, play_amount):
+    if hdc_side_win == play_side:
+        return_factor = return_factor
+    else:
+        return_factor = -1*return_factor
+        
+    return int(play_amount)*return_factor
